==> bootstrap-core-1.0.113-sources.jar: com/turbospaces/dispatch/EmbeddedTransactionalRequest.java <==
package com.turbospaces.dispatch;

import java.nio.file.Paths;
import java.util.Date;
import java.util.concurrent.CountDownLatch;

import org.apache.commons.lang3.concurrent.ConcurrentException;
import org.apache.commons.lang3.concurrent.LazyInitializer;

import com.google.protobuf.Any;
import com.google.protobuf.InvalidProtocolBufferException;
import com.google.protobuf.Message;
import com.turbospaces.common.PlatformUtil;
import com.turbospaces.executor.WorkUnit;

import api.v1.ObfuscatePrinter;
import api.v1.RequestWrapperFacade;
import lombok.extern.slf4j.Slf4j;

@Slf4j
public class EmbeddedTransactionalRequest<REQ extends Message, RESP extends Message.Builder> extends AbstractTransactionalRequest<REQ, RESP> {
    private final Date when;

    public EmbeddedTransactionalRequest(Class<REQ> reqType, RESP prototype, WorkUnit record, RequestWrapperFacade wrapper, CountDownLatch latch) {
        super(reqType, prototype, record, wrapper, latch);
        this.req = new LazyInitializer<REQ>() {
            @Override
            protected REQ initialize() throws ConcurrentException {
                Any body = wrapper.getBody();
                try {
                    REQ unpack = body.unpack(reqType);
                    log.debug("unpack: {}", ObfuscatePrinter.shortDebugString(unpack.toBuilder()));
                    return unpack;
                } catch (InvalidProtocolBufferException err) {
                    throw new ConcurrentException(err);
                }
            }
        };
        this.when = new Date();
    }
    @Override
    public REQ request() throws Exception {
        return req.get();
    }
    @Override
    public Date timestamp() {
        return when;
    }
    @Override
    public String jdbcOp(String... args) {
        Any body = wrapper.getBody();
        String typeUrl = PlatformUtil.toLowerUnderscore(body.getTypeUrl());
        return Paths.get(String.format("jdbc_%s", typeUrl), args).toString();
    }
    public static <T> String jdbcOp(T req, String... args) {
        String typeUrl = PlatformUtil.toLowerUnderscore(req.getClass().getSimpleName());
        return Paths.get(String.format("jdbc_%s", typeUrl), args).toString();
    }
}

==> bootstrap-core-1.0.116-sources.jar: com/turbospaces/dispatch/EmbeddedTransactionalRequest.java <==
package com.turbospaces.dispatch;

import java.nio.file.Paths;
import java.util.Date;
import java.util.concurrent.CountDownLatch;

import org.apache.commons.lang3.concurrent.ConcurrentException;
import org.apache.commons.lang3.concurrent.LazyInitializer;

import com.google.protobuf.Any;
import com.google.protobuf.InvalidProtocolBufferException;
import com.google.protobuf.Message;
import com.turbospaces.common.PlatformUtil;
import com.turbospaces.executor.WorkUnit;

import api.facade.RequestWrapperFacade;
import api.v1.ObfuscatePrinter;
import lombok.extern.slf4j.Slf4j;

@Slf4j
public class EmbeddedTransactionalRequest<REQ extends Message, RESP extends Message.Builder> extends AbstractTransactionalRequest<REQ, RESP> {
    private final Date when;

    public EmbeddedTransactionalRequest(Class<REQ> reqType, RESP prototype, WorkUnit record, RequestWrapperFacade wrapper, CountDownLatch latch) {
        super(reqType, prototype, record, wrapper, latch);
        this.req = new LazyInitializer<REQ>() {
            @Override
            protected REQ initialize() throws ConcurrentException {
                Any body = wrapper.body();
                try {
                    REQ unpack = body.unpack(reqType);
                    log.debug("unpack: {}", ObfuscatePrinter.shortDebugString(unpack.toBuilder()));
                    return unpack;
                } catch (InvalidProtocolBufferException err) {
                    throw new ConcurrentException(err);
                }
            }
        };
        this.when = new Date();
    }
    @Override
    public REQ request() throws Exception {
        return req.get();
    }
    @Override
    public Date timestamp() {
        return when;
    }
    @Override
    public String jdbcOp(String... args) {
        Any body = wrapper.body();
        String typeUrl = PlatformUtil.toLowerUnderscore(body.getTypeUrl());
        return Paths.get(String.format("jdbc_%s", typeUrl), args).toString();
    }
    public static <T> String jdbcOp(T req, String... args) {
        String typeUrl = PlatformUtil.toLowerUnderscore(req.getClass().getSimpleName());
        return Paths.get(String.format("jdbc_%s", typeUrl), args).toString();
    }
}
